@@ -1,21 +1,19 @@
-class TodomanException(Exception):
+class TodomanError(Exception):
     """
     Base class for all our exceptions.
 
     Should not be raised directly.
     """
 
-    pass
 
-
-class NoSuchTodo(TodomanException):
+class NoSuchTodoError(TodomanError):
     EXIT_CODE = 20
 
     def __str__(self):
         return f"No todo with id {self.args[0]}."
 
 
-class ReadOnlyTodo(TodomanException):
+class ReadOnlyTodoError(TodomanError):
     EXIT_CODE = 21
 
     def __str__(self):
@@ -26,7 +24,7 @@ class ReadOnlyTodo(TodomanException):
         )
 
 
-class NoListsFound(TodomanException):
+class NoListsFoundError(TodomanError):
     EXIT_CODE = 22
 
     def __str__(self):
@@ -35,7 +33,7 @@ class NoListsFound(TodomanException):
         )
 
 
-class AlreadyExists(TodomanException):
+class AlreadyExistsError(TodomanError):
     """
     Raised when two objects have a same identity.
 
