@@ -34,6 +34,7 @@ class TodoEditor:
             ("Summary", self._summary),
             ("Description", self._description),
             ("Location", self._location),
+            ("Categories", self._categories),
             ("Start", self._dtstart),
             ("Due", self._due),
             ("Completed", self._completed),
@@ -50,7 +51,7 @@ class TodoEditor:
             urwid.SimpleListWalker([grid, spacer, self._status, buttons])
         )
         right_column = urwid.ListBox(
-            urwid.SimpleListWalker([urwid.Text("List:\n")] + self.list_selector)
+            urwid.SimpleListWalker([urwid.Text("List:\n"), *self.list_selector])
         )
 
         self._ui = urwid.Columns([self.left_column, right_column])
@@ -65,6 +66,10 @@ class TodoEditor:
             edit_text=self.todo.description,
             multiline=True,
         )
+        self._categories = widgets.ExtendedEdit(
+            parent=self,
+            edit_text=self.formatter.format_categories(self.todo.categories),
+        )
         self._location = widgets.ExtendedEdit(
             parent=self,
             edit_text=self.todo.location,
@@ -104,11 +109,9 @@ class TodoEditor:
             " Ctrl-S: Save (only works if not a shell shortcut already)\n"
             "\n"
             "In Textfields:\n"
-            + "\n".join(" {}: {}".format(k, v) for k, v in widgets.ExtendedEdit.HELP)
+            + "\n".join(f" {k}: {v}" for k, v in widgets.ExtendedEdit.HELP)
             + "\n\nIn Priority Selector:\n"
-            + "\n".join(
-                " {}: {}".format(k, v) for k, v in widgets.PrioritySelector.HELP
-            )
+            + "\n".join(f" {k}: {v}" for k, v in widgets.PrioritySelector.HELP)
         )
 
     def _change_current_list(self, radio_button, new_state, new_list):
@@ -145,7 +148,7 @@ class TodoEditor:
         except Exception as e:
             self.set_status(("error", str(e)))
         else:
-            raise urwid.ExitMainLoop()
+            raise urwid.ExitMainLoop
 
     def _save_inner(self):
         self.todo.list = self.current_list
@@ -159,6 +162,7 @@ class TodoEditor:
         elif self.todo.is_completed and not self._completed.get_state():
             self.todo.status = "NEEDS-ACTION"
             self.todo.completed_at = None
+        self.todo.categories = [c.strip() for c in self.categories.split(",")]
         self.todo.priority = self.priority
 
         # TODO: categories
@@ -194,6 +198,10 @@ class TodoEditor:
     def dtstart(self):
         return self._dtstart.edit_text
 
+    @property
+    def categories(self):
+        return self._categories.edit_text
+
     @property
     def priority(self):
         return self._priority.priority
